using System;
using System.Web;
using System.Web.Hosting;

namespace BlogStarterKit
{
    public class Post
    {
        private long _postID = -1;
        public long PostID
        {
            get { return _postID; }
            set { _postID = value; }
        }

        private string _title;
        public string Title
        {
            get { return _title; }
            set { _title = value; }
        }

        private string _subtitle;
        public string Subtitle
        {
            get { return _subtitle; }
            set { _subtitle = value; }
        }

        private DateTime _datePosted;
        public DateTime DatePosted
        {
            get { return _datePosted; }
            set { _datePosted = value; _monthPosted = new DateTime(value.Year, value.Month, 1); }
        }

        private DateTime _monthPosted;
        public DateTime MonthPosted
        {
            get { return _monthPosted; }
            set { _monthPosted = value; }
        }

        private bool _draft;
        public bool Draft
        {
            get { return _draft; }
            set { _draft = value; }
        }

        private string _contents;
        public string Contents
        {
            get { return _contents; }
            set { _contents = value; }
        }

        private string _permalinkUrl;
        public string PermalinkUrl
        {
            get { return _permalinkUrl; }
            set { _permalinkUrl = value; }
        }

        private string _categoryName;
        public string CategoryName
        {
            get { return _categoryName; }
            set { _categoryName = value; }
        }

        private int _categoryID;
        public int CategoryID
        {
            get { return _categoryID; }
            set { _categoryID = value; }
        }

        private int _feedbackCount;
        public int FeedbackCount
        {
            get { return _feedbackCount; }
            set { _feedbackCount = value; }
        }

        public string PostUrl
        {
            get
            {
                string relativePath;
                if (String.IsNullOrEmpty(PermalinkUrl))
                {
                    relativePath = String.Format("Post.aspx?postID={0}", PostID);
                }
                else
                {
                    relativePath = PermalinkUrl;
                }

                HttpContext context = HttpContext.Current;

                return String.Format("{0}{1}/{2}",
                            context.Request.Url.GetLeftPart(UriPartial.Authority),
                            context.Request.ApplicationPath,
                            relativePath);
            }
        }

        private const int _excerptLength = 1024;
        public string Excerpt
        {
            get
            {
                string contents = Contents;
                if (contents.Length > _excerptLength)
                {
                    int n;
                    if ((n = contents.LastIndexOf("</p>", _excerptLength, _excerptLength, StringComparison.CurrentCultureIgnoreCase)) != -1)
                    {
                        contents = contents.Substring(0, n + 4);
                    }
                    else if ((n = contents.LastIndexOf(' ', _excerptLength, _excerptLength)) != -1)
                    {
                        contents = contents.Substring(0, n);
                    }
                    else
                    {
                        contents = contents.Substring(0, _excerptLength);
                    }
                }
                return contents;
            }
        }

        public bool IsExcerpted
        {
            get
            {
                return Contents.Length > _excerptLength;
            }
        }
    }
}